=============================
My Checker
=============================

.. image:: https://badge.fury.io/py/my_checker.png
    :target: http://badge.fury.io/py/my_checker

.. image:: https://travis-ci.org/mareuter/my_checker.png?branch=master
    :target: https://travis-ci.org/mareuter/my_checker

.. image:: https://pypip.in/d/my_checker/badge.png
    :target: https://pypi.python.org/pypi/my_checker


Quick math checker


Features
--------

* TODO

